AZURE_OPENAI_API_KEY=your-api-key
AZURE_OPENAI_ENDPOINT=https://your-resource.openai.azure.com/
AZURE_OPENAI_API_VERSION=2023-12-01-preview
AZURE_DEPLOYMENT_NAME=your-deployment-name

# Optional logging mode: none, jsonl, csv
RSCHAT_LOG_MODE=none
RSCHAT_LOG_PATH=chat_logs.jsonl

# [0] - Don't use Session Context | [1] - Use Session Context
RSCHAT_USE_CONTEXT=0
RSCHAT_SESSION_ID=default
RSCHAT_CONTEXT_MAX_MESSAGES=0
RSCHAT_CONTEXT_MAX_TOKENS=0
RSCHAT_CONTEXT_PATH=./.session
RSCHAT_OVERRIDE_SYSTEM=0
